@@ -54,6 +54,14 @@
 #error This MCU does not have SPI6
 #endif
 
+#if MYNEWT_VAL(MCU_STM32U5)
+/* DMA peripheral on STM32U5 is called GPDMA and macro to turn it's clock
+ * matches this name. For simplicity define old name __HAL_RCC_DMA1_CLK_ENABLE
+ * to defintion from U5 hal
+ */
+#define __HAL_RCC_DMA1_CLK_ENABLE __HAL_RCC_GPDMA1_CLK_ENABLE
+#endif
+
 /* Minimum transfer size when DMA should be used, for shorter transfers
  * interrupts are used
  */
@@ -613,13 +621,20 @@ spi_stm32_configure(struct bus_dev *bdev, struct bus_node *bnode)
     if (prescaler > 7) {
         rc = SYS_EINVAL;
     } else {
+#if MYNEWT_VAL(MCU_STM32H7) || MYNEWT_VAL(MCU_STM32U5)
+        dd->hspi.Init.BaudRatePrescaler = prescaler << SPI_CFG1_MBR_Pos;
+#else
         dd->hspi.Init.BaudRatePrescaler = prescaler << SPI_CR1_BR_Pos;
+#endif
         dd->hspi.Init.CLKPolarity = (node->mode == BUS_SPI_MODE_0 || node->mode == BUS_SPI_MODE_1) ?
                                     SPI_POLARITY_LOW : SPI_POLARITY_HIGH;
         dd->hspi.Init.CLKPhase = (node->mode == BUS_SPI_MODE_0 || node->mode == BUS_SPI_MODE_2) ?
                                  SPI_PHASE_1EDGE : SPI_PHASE_2EDGE;
         dd->hspi.Init.FirstBit = node->data_order == BUS_SPI_DATA_ORDER_MSB ?
                                  SPI_FIRSTBIT_MSB : SPI_FIRSTBIT_LSB;
+#if defined(SPI_MASTER_KEEP_IO_STATE_ENABLE)
+        dd->hspi.Init.MasterKeepIOState = SPI_MASTER_KEEP_IO_STATE_ENABLE;
+#endif
     }
     if (HAL_OK != HAL_SPI_Init(&dd->hspi)) {
         rc = SYS_EINVAL;
@@ -647,6 +662,14 @@ HAL_SPI_TxCpltCallback(SPI_HandleTypeDef *hspi)
     os_sem_release(&dd->sem);
 }
 
+void
+HAL_SPI_TxRxCpltCallback(SPI_HandleTypeDef *hspi)
+{
+    struct spi_stm32_driver_data *dd = (struct spi_stm32_driver_data *)hspi;
+
+    os_sem_release(&dd->sem);
+}
+
 static int
 spi_stm32_read(struct bus_dev *bdev, struct bus_node *bnode,
                uint8_t *buf, uint16_t length, os_time_t timeout,
@@ -732,6 +755,50 @@ spi_stm32_write(struct bus_dev *bdev, struct bus_node *bnode,
     return rc;
 }
 
+static int
+spi_stm32_duplex_write_read(struct bus_dev *bdev, struct bus_node *bnode,
+                            const uint8_t *wbuf, uint8_t *rbuf, uint16_t length,
+                            os_time_t timeout, uint16_t flags)
+{
+    struct bus_spi_dev *dev = (struct bus_spi_dev *)bdev;
+    struct bus_spi_node *node = (struct bus_spi_node *)bnode;
+    struct spi_stm32_driver_data *dd;
+    int rc;
+
+    BUS_DEBUG_VERIFY_DEV(dev);
+    BUS_DEBUG_VERIFY_NODE(node);
+
+    dd = driver_data(dev);
+
+    assert(os_sem_get_count(&dd->sem) == 0);
+
+    /* Activate CS */
+    if (node->pin_cs >= 0) {
+        hal_gpio_write(node->pin_cs, 0);
+    }
+
+    if (MIN_DMA_TX_SIZE >= 0 && length >= MIN_DMA_TX_SIZE) {
+        HAL_SPI_TransmitReceive_DMA(&dd->hspi, (uint8_t *)wbuf, rbuf, length);
+    } else {
+        HAL_SPI_TransmitReceive_IT(&dd->hspi, (uint8_t *)wbuf, rbuf, length);
+    }
+
+    rc = os_sem_pend(&dd->sem, timeout);
+
+    if (rc) {
+        HAL_SPI_Abort(&dd->hspi);
+    }
+
+    rc = os_error_to_sys(rc);
+
+    /* Deactivate CS if needed */
+    if ((rc != 0 || !(flags & BUS_F_NOSTOP)) && node->pin_cs >= 0) {
+        hal_gpio_write(node->pin_cs, 1);
+    }
+
+    return rc;
+}
+
 static int
 spi_stm32_enable(struct bus_dev *bdev)
 {
@@ -768,6 +835,7 @@ static const struct bus_dev_ops bus_spi_stm32_ops = {
     .read = spi_stm32_read,
     .write = spi_stm32_write,
     .disable = spi_stm32_disable,
+    .duplex_write_read = spi_stm32_duplex_write_read,
 };
 
 /* Helper function to setup interrupt handler for SPI and DMA */
@@ -829,6 +897,9 @@ bus_spi_stm32_dev_init_func(struct os_dev *odev, void *arg)
     dd->hspi.Init.NSS = SPI_NSS_SOFT;
     dd->hspi.Init.TIMode = SPI_TIMODE_DISABLE;
     dd->hspi.Init.CRCCalculation = SPI_CRCCALCULATION_DISABLE;
+#ifdef SPI_MASTER_KEEP_IO_STATE_ENABLE
+    dd->hspi.Init.MasterKeepIOState = SPI_MASTER_KEEP_IO_STATE_ENABLE;
+#endif
 
     if (MIN_DMA_RX_SIZE >= 0 || MIN_DMA_TX_SIZE >= 0) {
         dd->dmarx.Instance = spi_hw->dmarx_cfg->regs;
@@ -846,7 +917,7 @@ bus_spi_stm32_dev_init_func(struct os_dev *odev, void *arg)
             __HAL_RCC_DMA2_CLK_ENABLE();
 #endif
         }
-#ifdef DMAMUX1
+#ifdef __HAL_RCC_DMAMUX1_CLK_ENABLE
         __HAL_RCC_DMAMUX1_CLK_ENABLE();
 #endif
 
