@@ -22,7 +22,7 @@
 #include <i2s/i2s.h>
 #include <i2s/i2s_driver.h>
 #include <i2s_nrf52/i2s_nrf52.h>
-#include <nrfx/drivers/include/nrfx_i2s.h>
+#include <drivers/include/nrfx_i2s.h>
 
 struct nrf52_i2s {
     nrfx_i2s_config_t nrfx_i2s_cfg;
