@@ -20,20 +20,45 @@
 #include <errno.h>
 #include <os/os.h>
 #include <ipc_nrf5340/ipc_nrf5340.h>
-#include <ipc_nrf5340/ipc_nrf5340_priv.h>
 #include <nrfx.h>
-#include <hal/hal_gpio.h>
-#include <bsp.h>
-#include <nrf_mutex.h>
-#if MYNEWT_VAL(BLE_TRANSPORT_INT_FLOW_CTL)
-#include <nimble/transport.h>
-#endif
 
 #if MYNEWT_VAL(IPC_NRF5340_NET_GPIO)
 #include <mcu/nrf5340_hal.h>
 #include <bsp/bsp.h>
 #endif
 
+#if MYNEWT_PKG_apache_mynewt_nimble__nimble_transport_common_hci_ipc
+#include <nimble/transport/hci_ipc.h>
+#endif
+
+#define NRF_APP_IPC_NS                  ((NRF_IPC_Type *)0x4002A000)
+#define NRF_APP_IPC_S                   ((NRF_IPC_Type *)0x5002A000)
+
+/**
+ * Initialization structure passed from APP core to NET core.
+ * Keeps various parameters that otherwise should be configured on
+ * both sides.
+ */
+struct ipc_shared {
+    /** NET core embedded image address in application flash */
+    void *net_core_image_address;
+    /** NET core embedded image size */
+    uint32_t net_core_image_size;
+    /** Number of IPC channels */
+    uint8_t ipc_channel_count;
+    /* Array of shared memories used for IPC */
+    struct ipc_shm *ipc_shms;
+    /* Set by netcore during IPC initialization */
+    volatile enum {
+        APP_WAITS_FOR_NET,
+        APP_AND_NET_RUNNING,
+        NET_RESTARTED,
+    } ipc_state;
+#if MYNEWT_PKG_apache_mynewt_nimble__nimble_transport_common_hci_ipc
+    volatile struct hci_ipc_shm hci_shm;
+#endif
+};
+
 /* Currently this allows only for 1-1 connection. */
 
 #define IPC_MAX_CHANS MYNEWT_VAL(IPC_NRF5340_CHANNELS)
@@ -239,6 +264,8 @@ ipc_nrf5340_init(void)
     NRF_GPIO_Type *nrf_gpio;
 #endif
 
+    memset(ipc_shared, 0, sizeof(ipc_shared));
+
 #if MYNEWT_VAL(NRF5340_EMBED_NET_CORE)
     /*
      * Get network core image size and placement in application flash.
@@ -271,10 +298,6 @@ ipc_nrf5340_init(void)
     ipc_shared->ipc_shms = shms;
     ipc_shared->ipc_state = APP_WAITS_FOR_NET;
 
-#if MYNEWT_VAL(BLE_TRANSPORT_INT_FLOW_CTL)
-    ipc_shared->acl_from_ll_count = MYNEWT_VAL(BLE_TRANSPORT_ACL_FROM_LL_COUNT);
-#endif
-
     if (MYNEWT_VAL(MCU_APP_SECURE) && !MYNEWT_VAL(IPC_NRF5340_PRE_TRUSTZONE_NETCORE_BOOT)) {
         /*
          * When bootloader is secure and application is not all peripherals are
@@ -304,7 +327,14 @@ ipc_nrf5340_init(void)
     }
 
     /* Start Network Core */
+    /* Workaround for Errata 161: "RESET: Core is not fully reset after Force-OFF" */
+    *(volatile uint32_t *) ((uint32_t)NRF_RESET + 0x618ul) = 1ul;
     NRF_RESET->NETWORK.FORCEOFF = RESET_NETWORK_FORCEOFF_FORCEOFF_Release;
+    os_cputime_delay_usecs(5);
+    NRF_RESET->NETWORK.FORCEOFF = RESET_NETWORK_FORCEOFF_FORCEOFF_Hold;
+    os_cputime_delay_usecs(1);
+    NRF_RESET->NETWORK.FORCEOFF = RESET_NETWORK_FORCEOFF_FORCEOFF_Release;
+    *(volatile uint32_t *) ((uint32_t)NRF_RESET + 0x618ul) = 0;
 
     /*
      * Waits for NET core to start and init it's side of IPC.
@@ -391,6 +421,12 @@ ipc_nrf5340_recv(int channel, ipc_nrf5340_recv_cb cb, void *user_data)
 
 int
 ipc_nrf5340_send(int channel, const void *data, uint16_t len)
+{
+    return ipc_nrf5340_write(channel, data, len, true);
+}
+
+int
+ipc_nrf5340_write(int channel, const void *data, uint16_t len, bool last)
 {
     struct ipc_shm *shm;
     uint16_t frag_len;
@@ -417,7 +453,9 @@ ipc_nrf5340_send(int channel, const void *data, uint16_t len)
 
             frag_len = min(len, space);
             ipc_nrf5340_shm_write(shm, data, frag_len);
-            NRF_IPC->TASKS_SEND[channel] = 1;
+            if (last || len > space) {
+                NRF_IPC->TASKS_SEND[channel] = 1;
+            }
 
             data += frag_len;
             len -= frag_len;
@@ -446,10 +484,7 @@ ipc_nrf5340_read_om(int channel, struct os_mbuf *om, uint16_t len)
 uint16_t
 ipc_nrf5340_available(int channel)
 {
-    assert(channel < IPC_MAX_CHANS);
-
-    return ipc_nrf5340_shm_get_data_length(shms[channel].head,
-                                           shms[channel].tail);
+    return ipc_nrf5340_data_available_get(channel);
 }
 
 uint16_t
@@ -470,6 +505,21 @@ ipc_nrf5340_available_buf(int channel, void **dptr)
     return 0;
 }
 
+uint16_t
+ipc_nrf5340_data_available_get(int channel)
+{
+    assert(channel < IPC_MAX_CHANS);
+
+    return ipc_nrf5340_shm_get_data_length(shms[channel].head,
+                                           shms[channel].tail);
+}
+
+uint16_t
+ipc_nrf5340_data_free_get(int channel)
+{
+    return IPC_BUF_SIZE - ipc_nrf5340_data_available_get(channel) - 1;
+}
+
 uint16_t
 ipc_nrf5340_consume(int channel, uint16_t len)
 {
@@ -478,40 +528,33 @@ ipc_nrf5340_consume(int channel, uint16_t len)
     return ipc_nrf5340_shm_read(&shms[channel], NULL, NULL, len);
 }
 
-#if MYNEWT_VAL(BLE_TRANSPORT_INT_FLOW_CTL)
-int
-ble_transport_int_flow_ctl_get(void)
+#if MYNEWT_VAL(MCU_NET_CORE)
+const void *
+ipc_nrf5340_net_image_get(uint32_t *size)
 {
-    int ret;
+    const void *img_addr;
+    uint32_t image_size;
 
-    __asm__ volatile (".syntax unified                \n"
-                      "1: ldrexb r1, [%[addr]]        \n"
-                      "   mov %[ret], r1              \n"
-                      "   cmp r1, #0                  \n"
-                      "   itte ne                     \n"
-                      "   subne r2, r1, #1            \n"
-                      "   strexbne r1, r2, [%[addr]]  \n"
-                      "   clrexeq                     \n"
-                      "   cmp r1, #0                  \n"
-                      "   bne 1b                      \n"
-                      : [ret] "=&r" (ret)
-                      : [addr] "r"(&ipc_shared->acl_from_ll_count)
-                      : "r1", "r2", "memory");
+#if MYNEWT_VAL(IPC_NRF5340_PRE_TRUSTZONE_NETCORE_BOOT)
+    img_addr = (const void *)NRF_APP_IPC_S->GPMEM[0];
+    image_size = (uint32_t)NRF_APP_IPC_S->GPMEM[1];
+#else
+    img_addr = ipc_shared[0].net_core_image_address;
+    image_size = ipc_shared[0].net_core_image_size;
+#endif
 
-    return ret;
-}
+    if (size) {
+        *size = image_size;
+    }
 
-void
-ble_transport_int_flow_ctl_put(void)
+    return img_addr;
+}
+#endif
+
+#if MYNEWT_PKG_apache_mynewt_nimble__nimble_transport_common_hci_ipc
+volatile struct hci_ipc_shm *
+ipc_nrf5340_hci_shm_get(void)
 {
-    __asm__ volatile (".syntax unified              \n"
-                      "1: ldrexb r1, [%[addr]]      \n"
-                      "   add r1, r1, #1            \n"
-                      "   strexb r2, r1, [%[addr]]  \n"
-                      "   cmp r2, #0                \n"
-                      "   bne 1b                    \n"
-                      :
-                      : [addr] "r"(&ipc_shared->acl_from_ll_count)
-                      : "r1", "r2", "memory");
+    return &ipc_shared->hci_shm;
 }
 #endif
