@@ -26,6 +26,8 @@
 #include "mcu/da1469x_pdc.h"
 #include "mcu/da1469x_prail.h"
 #include "hal/hal_system.h"
+#include "hal/hal_debug.h"
+#include "os/os_arch.h"
 #include "os/os_cputime.h"
 
 #if !MYNEWT_VAL(BOOT_LOADER)
@@ -137,6 +139,9 @@ hal_system_clock_start(void)
      */
     da1469x_clock_lp_rcx_disable();
 #endif
+
+    /* TODO: we should calibrate this periodically */
+    da1469x_clock_lp_rc32k_calibrate();
 }
 
 enum hal_reset_reason
