@@ -61,13 +61,12 @@ static const struct periph_id_range ns_peripheral_ids[] = {
 #define STRIP_PARENS(X) X
 #define UNMANGLE_MYNEWT_VAL(X) STRIP_PARENS(_Args X)
 
-#if MYNEWT_VAL(MCU_GPIO_NET)
-static const unsigned int net_gpios[] = { UNMANGLE_MYNEWT_VAL(MYNEWT_VAL(MCU_GPIO_NET)) };
-#endif
 #if MYNEWT_VAL(MCU_GPIO_PERIPH)
 static const unsigned int periph_gpios[] = { UNMANGLE_MYNEWT_VAL(MYNEWT_VAL(MCU_GPIO_PERIPH)) };
 #endif
 
+extern uint8_t __StackTop[];
+
 void
 hal_system_start(void *img_start)
 {
@@ -119,12 +118,6 @@ hal_system_start(void *img_start)
     NRF_SPU->GPIOPORT[0].PERM = 0;
     NRF_SPU->GPIOPORT[1].PERM = 0;
 
-#if MYNEWT_VAL(MCU_GPIO_NET)
-    for (i = 0; i < ARRAY_SIZE(net_gpios); ++i) {
-        nrf_gpio_pin_mcu_select(net_gpios[i], GPIO_PIN_CNF_MCUSEL_NetworkMCU);
-    }
-#endif
-
 #if MYNEWT_VAL(MCU_GPIO_PERIPH)
     for (i = 0; i < ARRAY_SIZE(periph_gpios); ++i) {
         nrf_gpio_pin_mcu_select(periph_gpios[i], GPIO_PIN_CNF_MCUSEL_Peripheral);
@@ -142,13 +135,12 @@ hal_system_start(void *img_start)
      * Normal loop here is inlined by GCC to call to memset hence asm version of
      * memset that does not use stack (that just get erased).
      */
-    asm volatile("    add     %1, %1, %0    \n"
-                 "    mov     r0, #0        \n"
+    asm volatile("    mov     r0, #0        \n"
                  "1:  stmia   %0!, {r0}     \n"
                  "    cmp     %0, %1        \n"
                  "    blt     1b            \n"
         :
-        : "r" (&_ram_start), "r" (RAM_SIZE)
+        : "r" (&_ram_start), "r" (&__StackTop)
         : "r0");
     /* Application startup code expects interrupts to be enabled */
     __enable_irq();
