@@ -253,6 +253,14 @@ spi_irq_handler(struct stm32_hal_spi *spi)
 }
 #endif
 
+#if !defined(SPI_IT_TXE) && defined(SPI_IT_TXP)
+#define SPI_IT_TXE                      SPI_IT_TXP
+#endif
+#if !defined(SPI_IT_RXNE) && defined(SPI_IT_RXP)
+#define SPI_IT_RXNE                     SPI_IT_RXP
+#define SPI_SR_RXNE                     SPI_SR_RXP
+#endif
+
 /*
  * GPIO interrupt when slave gets selected/deselected.
  */
@@ -286,10 +294,15 @@ spi_ss_isr(void *arg)
         /*
          * Chip select done. Check whether there's pending data to RX.
          */
+#if MYNEWT_VAL(MCU_STM32H7)
+        if (spi->handle.Instance->SR & SPI_SR_RXP && spi->handle.RxISR) {
+            spi->handle.RxISR(&spi->handle);
+        }
+#else
         if (spi->handle.Instance->SR & SPI_SR_RXNE && spi->handle.RxISR) {
             spi->handle.RxISR(&spi->handle);
         }
-
+#endif
         /*
          * Disable SPI.
          */
@@ -430,6 +443,41 @@ hal_spi_init(int spi_num, void *usercfg, uint8_t spi_type)
 
     spi->cfg = usercfg;
     spi->slave = (spi_type == HAL_SPI_TYPE_SLAVE);
+    switch (spi_num) {
+#if SPI_0_ENABLED
+    case 0:
+        spi->handle.Instance = SPI1;
+        break;
+#endif
+#if SPI_1_ENABLED
+    case 1:
+        spi->handle.Instance = SPI2;
+        break;
+#endif
+#if SPI_2_ENABLED
+    case 2:
+        spi->handle.Instance = SPI3;
+        break;
+#endif
+#if SPI_3_ENABLED
+    case 3:
+        spi->handle.Instance = SPI4;
+        break;
+#endif
+#if SPI_4_ENABLED
+    case 4:
+        spi->handle.Instance = SPI5;
+        break;
+#endif
+#if SPI_5_ENABLED
+    case 5:
+        spi->handle.Instance = SPI6;
+        break;
+#endif
+    default:
+        rc = -1;
+        goto err;
+    }
 
     return (0);
 err:
@@ -474,7 +522,11 @@ stm32_spi_resolve_prescaler(uint8_t spi_num, uint32_t baudrate, uint32_t *presca
     for (i = 0; i < 8; i++) {
         candidate_br = apbfreq >> (i + 1);
         if (candidate_br <= baudrate) {
+#if defined(SPI_CR1_BR_Pos)
             *prescaler = i << SPI_CR1_BR_Pos;
+#else
+            *prescaler = i << SPI_CFG1_MBR_Pos;
+#endif
             break;
         }
     }
@@ -611,7 +663,6 @@ hal_spi_config(int spi_num, struct hal_spi_settings *settings)
         gpio.Alternate = GPIO_AF0_SPI1;
     #endif
 #endif
-        spi->handle.Instance = SPI1;
         break;
 #endif
 #if SPI_1_ENABLED
@@ -624,7 +675,6 @@ hal_spi_config(int spi_num, struct hal_spi_settings *settings)
         gpio.Alternate = GPIO_AF0_SPI2;
     #endif
 #endif
-        spi->handle.Instance = SPI2;
         break;
 #endif
 #if SPI_2_ENABLED
@@ -633,7 +683,6 @@ hal_spi_config(int spi_num, struct hal_spi_settings *settings)
 #if !MYNEWT_VAL(MCU_STM32F1)
         gpio.Alternate = GPIO_AF6_SPI3;
 #endif
-        spi->handle.Instance = SPI3;
         break;
 #endif
 #if SPI_3_ENABLED
@@ -642,7 +691,6 @@ hal_spi_config(int spi_num, struct hal_spi_settings *settings)
 #if !MYNEWT_VAL(MCU_STM32F1)
         gpio.Alternate = GPIO_AF5_SPI4;
 #endif
-        spi->handle.Instance = SPI4;
         break;
 #endif
 #if SPI_4_ENABLED
@@ -653,7 +701,6 @@ hal_spi_config(int spi_num, struct hal_spi_settings *settings)
 #elif defined(GPIO_AF5_SPI5)
         gpio.Alternate = GPIO_AF5_SPI5;
 #endif
-        spi->handle.Instance = SPI5;
         break;
 #endif
 #if SPI_5_ENABLED
@@ -662,7 +709,6 @@ hal_spi_config(int spi_num, struct hal_spi_settings *settings)
 #if !MYNEWT_VAL(MCU_STM32F1)
         gpio.Alternate = GPIO_AF5_SPI6;
 #endif
-        spi->handle.Instance = SPI6;
         break;
 #endif
    default:
@@ -912,13 +958,12 @@ uint16_t hal_spi_tx_val(int spi_num, uint16_t val)
 {
     int rc;
     struct stm32_hal_spi *spi;
-    uint16_t retval;
+    uint16_t retval = 0xFFFF;
     int len;
     int sr;
 
     STM32_HAL_SPI_RESOLVE(spi_num, spi);
     if (spi->slave) {
-        retval = -1;
         goto err;
     }
     if (spi->handle.Init.DataSize == SPI_DATASIZE_8BIT) {
