@@ -134,12 +134,17 @@ static struct hal_uart_irq uart_irqs[3];
 
 #if !MYNEWT_VAL(STM32_HAL_UART_HAS_SR)
 #  define STATUS(x)     ((x)->ISR)
+#if MYNEWT_VAL(MCU_STM32H7)
+#  define RXNE          USART_ISR_RXNE_RXFNE
+#  define TXE           USART_ISR_TXE_TXFNF
+#else
 #  define RXNE          USART_ISR_RXNE
 #  define TXE           USART_ISR_TXE
+#endif
 #  define TC            USART_ISR_TC
 #  define RXDR(x)       ((x)->RDR)
 #  define TXDR(x)       ((x)->TDR)
-#if MYNEWT_VAL(MCU_STM32WB)
+#if MYNEWT_VAL(MCU_STM32WB) || MYNEWT_VAL(MCU_STM32H7) || MYNEWT_VAL(MCU_STM32U5)
 #  define BAUD(x,y)     UART_DIV_SAMPLING16((x), (y), UART_PRESCALER_DIV1)
 #else
 #  define BAUD(x,y)     UART_DIV_SAMPLING16((x), (y))
