@@ -17,8 +17,6 @@
 #
 . $CORE_PATH/hw/scripts/common.sh
 
-GDB=arm-none-eabi-gdb
-
 #
 # FILE_NAME must contain the name of the file to load
 # FLASH_OFFSET must contain the offset in flash where to place it
@@ -58,6 +56,8 @@ stlink_load () {
 #
 stlink_debug () {
     windows_detect
+    gdb_detect
+
     PORT=3333
 
     parse_extra_jtag_cmd $EXTRA_JTAG_CMD
