@@ -24,12 +24,18 @@
 
 #define CFG_TUSB_RHPORT0_SPEED  OPT_MODE_FULL_SPEED
 
+#ifndef CFG_TUSB_RHPORT1_MODE
+#define CFG_TUSB_RHPORT1_MODE   OPT_MODE_NONE
+#endif
+
 #if MYNEWT_VAL(MCU_STM32F4)
 #define CFG_TUSB_MCU OPT_MCU_STM32F4
 #elif MYNEWT_VAL(MCU_STM32F7)
 #define CFG_TUSB_MCU OPT_MCU_STM32F7
 #elif MYNEWT_VAL(MCU_STM32L4)
 #define CFG_TUSB_MCU OPT_MCU_STM32L4
+#elif MYNEWT_VAL(MCU_STM32U5)
+#define CFG_TUSB_MCU OPT_MCU_STM32U5
 #endif
 
 #if defined(MYNEWT_VAL_USBD_CDC_NOTIFY_EP)
@@ -80,4 +86,16 @@
 #define USBD_HID_REPORT_EP_INTERVAL 10
 #endif
 
+#if defined(MYNEWT_VAL_USBD_MSC_DATA_IN_EP)
+#define USBD_MSC_DATA_IN_EP     MYNEWT_VAL(USBD_MSC_DATA_IN_EP)
+#else
+#define USBD_MSC_DATA_IN_EP     0x83
+#endif
+
+#if defined(MYNEWT_VAL_USBD_MSC_DATA_OUT_EP)
+#define USBD_MSC_DATA_OUT_EP     MYNEWT_VAL(USBD_MSC_DATA_OUT_EP)
+#else
+#define USBD_MSC_DATA_OUT_EP     0x03
+#endif
+
 #endif
